@@ -11,6 +11,7 @@ from enum import Enum
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Union
 
 
 class HttpMethod(Enum):
@@ -133,10 +134,10 @@ class SchemaObject:
     id: str
     title: Optional[str]
     required: Optional[List[str]]
-    enum: List[str]
+    enum: Optional[List[str]]
     type: Type
-    format: Optional[str]
-    items: Optional['SchemaObject']
+    format: Optional[Format]
+    items: Optional[Union['SchemaObject', List['SchemaObject']]]
     properties: List[SchemaProperty]
     description: Optional[str] = None
 
@@ -219,9 +220,10 @@ class OperationObject:
         return [parameter for parameter in self.parameters if parameter.location == ParameterLocation.header]
 
     @property
-    def fn_name(self) -> str:
-        value = self.operation_id.replace('-', '_')
-        return value
+    def fn_name(self) -> Optional[str]:
+        if self.operation_id is not None:
+            return self.operation_id.replace('-', '_')
+        return None
 
 
 @dataclass
@@ -258,7 +260,7 @@ class Document:
 
     @property
     def sorted_schemas(self) -> List[SchemaObject]:
-        sorted = []
+        sorted: List[str] = []
         keys = list(self.schemas.keys())
         while keys:
             key = keys.pop()
@@ -272,8 +274,13 @@ class Document:
             for property in schema.properties:
                 if property.schema.id in self.schemas and property.schema.id not in sorted:
                     sorted.insert(index, property.schema.id)
-                if property.schema.items and property.schema.items.id in self.schemas:
-                    sorted.insert(index, property.schema.items.id)
+                if property.schema.items:
+                    if isinstance(property.schema.items, list):
+                        for items in property.schema.items:
+                            if items.id in self.schemas:
+                                sorted.insert(index, items.id)
+                    elif property.schema.items.id in self.schemas:
+                        sorted.insert(index, property.schema.items.id)
 
         sorted_schemas = []
         for key in sorted:
